@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -28,30 +28,30 @@ def getImporterInfo(sourceId):
         (string)
     @exception ValueError raised to indicate an invalid browser ID
     """
-    if sourceId == "opera":
-        if Globals.isWindowsPlatform():
-            standardDir = os.path.expandvars("%APPDATA%\\Opera\\Opera")
-        elif Globals.isMacPlatform():
-            standardDir = os.path.expanduser(
-                "~/Library/Opera")
-        else:
-            standardDir = os.path.expanduser("~/.opera")
-        return (
-            UI.PixmapCache.getPixmap("opera"),
-            "Opera",
-            "bookmarks.adr",
-            QCoreApplication.translate(
-                "OperaImporter",
-                """Opera stores its bookmarks in the <b>bookmarks.adr</b> """
-                """text file. This file is usually located in"""),
-            QCoreApplication.translate(
-                "OperaImporter",
-                """Please choose the file to begin importing bookmarks."""),
-            standardDir,
-        )
-    else:
+    if sourceId != "opera":
         raise ValueError(
             "Unsupported browser ID given ({0}).".format(sourceId))
+    
+    if Globals.isWindowsPlatform():
+        standardDir = os.path.expandvars("%APPDATA%\\Opera\\Opera")
+    elif Globals.isMacPlatform():
+        standardDir = os.path.expanduser(
+            "~/Library/Opera")
+    else:
+        standardDir = os.path.expanduser("~/.opera")
+    return (
+        UI.PixmapCache.getPixmap("opera"),
+        "Opera",
+        "bookmarks.adr",
+        QCoreApplication.translate(
+            "OperaImporter",
+            """Opera stores its bookmarks in the <b>bookmarks.adr</b> """
+            """text file. This file is usually located in"""),
+        QCoreApplication.translate(
+            "OperaImporter",
+            """Please choose the file to begin importing bookmarks."""),
+        standardDir,
+    )
 
 
 class OperaImporter(BookmarksImporter):
@@ -65,7 +65,7 @@ class OperaImporter(BookmarksImporter):
         @param sourceId source ID (string)
         @param parent reference to the parent object (QObject)
         """
-        super(OperaImporter, self).__init__(sourceId, parent)
+        super().__init__(sourceId, parent)
         
         self.__fileName = ""
     
@@ -132,5 +132,6 @@ class OperaImporter(BookmarksImporter):
         else:
             importRootNode.title = self.tr(
                 "Imported {0}"
-            ).format(QDate.currentDate().toString(Qt.SystemLocaleShortDate))
+            ).format(QDate.currentDate().toString(
+                Qt.DateFormat.SystemLocaleShortDate))
         return importRootNode
